Module hover

Module hover 

Hover documentation for .nautilus schema files.

Structs

HoverInfo
Information to display when hovering over a token.

Functions

config_field_hover
Hover documentation for datasource/generator config fields.
hover
Returns hover documentation for the symbol at byte offset in source.
hover_with_analysis
Returns hover documentation for the symbol at offset using a previously computed AnalysisResult.