pub fn hover_with_analysis(
_source: &str,
result: &AnalysisResult,
offset: usize,
) -> Option<HoverInfo>Expand description
Returns hover documentation for the symbol at offset using a previously
computed AnalysisResult.
pub fn hover_with_analysis(
_source: &str,
result: &AnalysisResult,
offset: usize,
) -> Option<HoverInfo>Returns hover documentation for the symbol at offset using a previously
computed AnalysisResult.