ScalarType

Enum ScalarType 

pub enum ScalarType {
Show 14 variants String, Boolean, Int, BigInt, Float, Decimal { precision: u32, scale: u32, }, DateTime, Bytes, Json, Uuid, Jsonb, Xml, Char { length: u32, }, VarChar { length: u32, },
}
Scalar type enumeration.

Variants



String

UTF-8 string type.



Boolean

Boolean type (true/false).



Int

32-bit integer.



BigInt

64-bit integer.



Float

64-bit floating point.



Decimal

Fixed-precision decimal number.

Fields

precision: u32

Number of total digits.

scale: u32

Number of digits after decimal point.



DateTime

Date and time.



Bytes

Binary data.



Json

JSON value.



Uuid

UUID value.



Jsonb

JSONB value (PostgreSQL only).



Xml

XML value (PostgreSQL only).



Char

Fixed-length character type.

Fields

length: u32

Column length.



VarChar

Variable-length character type.

Fields

length: u32

Maximum column length.

Implementations

Source

impl ScalarType

pub fn rust_type(&self) -> &'static str

Returns the Rust type name for this scalar type.

pub fn supported_by(self, provider: DatabaseProvider) -> bool

Returns true when this scalar type is supported by the given database provider.

pub fn supported_providers(self) -> &'static str

Human-readable list of supported providers (for diagnostics).