pub struct SchemaIr {
pub datasource: Option<DatasourceIr>,
pub generator: Option<GeneratorIr>,
pub models: HashMap<String, ModelIr>,
pub enums: HashMap<String, EnumIr>,
pub composite_types: HashMap<String, CompositeTypeIr>,
}Expand description
Validated intermediate representation of a complete schema.
Fields
datasource: Option<DatasourceIr>The datasource declaration (if present).
generator: Option<GeneratorIr>The generator declaration (if present).
models: HashMap<String, ModelIr>All models in the schema, indexed by logical name.
enums: HashMap<String, EnumIr>All enums in the schema, indexed by logical name.
composite_types: HashMap<String, CompositeTypeIr>All composite types in the schema, indexed by logical name.
Implementations
Sourceimpl SchemaIr
impl SchemaIr
Sourcepub fn get_composite_type(&self, name: &str) -> Option<&CompositeTypeIr>
pub fn get_composite_type(&self, name: &str) -> Option<&CompositeTypeIr>
Gets a composite type by logical name.