pub enum DatabaseProvider {
Postgres,
Mysql,
Sqlite,
}Expand description
The three datasource providers recognised by the Nautilus schema language.
Obtained by parsing the provider field of a datasource block:
datasource db {
provider = "postgresql" // -> DatabaseProvider::Postgres
}Variants
Postgres
PostgreSQL (provider string: "postgresql").
Mysql
MySQL / MariaDB (provider string: "mysql").
Sqlite
SQLite (provider string: "sqlite").
Implementations