parse_sql_expr

Function parse_sql_expr 

pub fn parse_sql_expr(tokens: &[Token], fallback_span: Span) -> Result<SqlExpr>
Parse a slice of schema tokens into a validated SqlExpr tree.

The token slice should contain only the expression tokens (i.e. without the surrounding @computed(, Stored) scaffolding).

fallback_span is used for error reporting when the slice is empty.